Module types

Module types 

Various types returned from sysfs’s properties.

Structs

Milliamps
A number with the unit mA.
Millivolts
A number with the unit mV.
Milliwatts
A number with the unit mW.
Revision
A [major].[minor] version.
RoleSelection
A single role selected from a potentially-dual-role property.
SupportedRoles
VdoCertStat
An XID from a USB-IF-certified device.
VdoIdHeader
ID Header VDO (6.4.4.3.1.1)
VdoIdHeaderCable
A parsed identity header from a crate::sysfs::Cable.
VdoIdHeaderPartner
A parsed identity header from a crate::sysfs::Partner.
VdoProduct

Enums

CableType
The type of a USB-C cable.
ConnectorType
The type of a crate::sysfs::Partner’s connector, as read from the identity header.
DataRole
A port’s role in data transmission.
FastRoleSwapCurrent
The current required by a sink after a fast role swap.
PeakCurrent
The extent of the PDO’s ability to overload the current for a short period of time.
PlugType
PortType
PowerOperationMode
PowerRole
A port’s role in power transmission.
ProductTypeCable
The type of a crate::sysfs::Cable, as read from the identity header.
ProductTypePartnerDfp
ProductTypePartnerUfp