pub struct IdentityPartner<'fd> { /* private fields */ }Expand description
A handle to a Partner’s identity information.
Implementations
Sourceimpl IdentityPartner<'_>
impl IdentityPartner<'_>
Sourcepub fn id_header(&self) -> impl PropertyReadable<Read = VdoIdHeaderPartner> + '_
pub fn id_header(&self) -> impl PropertyReadable<Read = VdoIdHeaderPartner> + '_
The identity header.
If this property is not available yet, then calling PropertyReadable::get
will return Error::IdentityUnavailable.
Sourcepub fn cert_stat(&self) -> impl PropertyReadable<Read = VdoCertStat> + '_
pub fn cert_stat(&self) -> impl PropertyReadable<Read = VdoCertStat> + '_
The XID from a USB-IF certified device.
If this property is not available, either because it has not been determined yet
or the device is not USB-IF certified, then calling PropertyReadable::get
will return Error::IdentityUnavailable.
Sourcepub fn product(&self) -> impl PropertyReadable<Read = VdoProduct> + '_
pub fn product(&self) -> impl PropertyReadable<Read = VdoProduct> + '_
The product IDs.
If this property is not available yet, then calling PropertyReadable::get
will return Error::IdentityUnavailable.
pub fn product_type_vdo1(&self) -> impl PropertyReadable<Read = u32> + '_
pub fn product_type_vdo2(&self) -> impl PropertyReadable<Read = u32> + '_
pub fn product_type_vdo3(&self) -> impl PropertyReadable<Read = u32> + '_