Various types returned from sysfs’s properties.
Structs
- Milliamps
- A number with the unit mA.
- Millivolts
- A number with the unit mV.
- Milliwatts
- A number with the unit mW.
- Revision
- A
[major].[minor]version. - Role
Selection - A single role selected from a potentially-dual-role property.
- Supported
Roles - VdoCert
Stat - An XID from a USB-IF-certified device.
- VdoId
Header - ID Header VDO (6.4.4.3.1.1)
- VdoId
Header Cable - A parsed identity header from a
crate::sysfs::Cable. - VdoId
Header Partner - A parsed identity header from a
crate::sysfs::Partner. - VdoProduct
Enums
- Cable
Type - The type of a USB-C cable.
- Connector
Type - The type of a
crate::sysfs::Partner’s connector, as read from the identity header. - Data
Role - A port’s role in data transmission.
- Fast
Role Swap Current - The current required by a sink after a fast role swap.
- Peak
Current - The extent of the PDO’s ability to overload the current for a short period of time.
- Plug
Type - Port
Type - Power
Operation Mode - Power
Role - A port’s role in power transmission.
- Product
Type Cable - The type of a
crate::sysfs::Cable, as read from the identity header. - Product
Type Partner Dfp - Product
Type Partner Ufp